@@ -51,21 +51,15 @@
 #include <Python.h> /* make sure Python.h is first */
 #include <stdlib.h>
 #include "ferret.h"
+#include "FerMem.h"
 
- 
+void FORTRAN(free_cached_full_array)(double **pointer_val)
 /*
   see complementary routines recover_cached_full_array and cache_full_array.c
 */
-void FORTRAN(free_cached_full_array)( double **pointer_val )
 {
-  double *ptr;
-
-  ptr = *pointer_val;
-
-  if (ptr) {
-	  PyMem_Free(ptr);
-	  *pointer_val=0;
+  if ( *pointer_val != NULL ) {
+      FerMem_Free(*pointer_val, __FILE__, __LINE__);
+      *pointer_val = NULL;
   }
-
-  return;
 }
