@@ -6,6 +6,7 @@
 #include <netinet/in.h> /* for htonl; header probably varies by platform */
 #include <assert.h>
 #include "ferret.h"
+#include "FerMem.h"
 
 /*
  * if clobber == 0, open filename for overwriting.
@@ -38,8 +39,7 @@
  *                          fine as long as length is less than 2e31.
  */
 
-int FORTRAN(write_dods)(char*filename, int* slen, int *clobber, int *swap, 
-                        int *length, float *data) 
+int FORTRAN(write_dods)(char*filename, int* slen, int *clobber, int *swap, int *length, float *data) 
 {
   FILE *f;
   int i, length_n, result = 0;
@@ -56,7 +56,8 @@ int FORTRAN(write_dods)(char*filename, int* slen, int *clobber, int *swap,
 
   /* allocate memory and save the filename to null-terminated string */
 
-  if ( fileptr = (char *) PyMem_Malloc(sizeof(char) * (*slen + 1) ) ) {
+  fileptr = (char *) FerMem_Malloc(sizeof(char) * (*slen + 1), __FILE__, __LINE__);
+  if ( fileptr != NULL ) {
     strncpy (fileptr, filename, *slen);
     fileptr[*slen] = 0;    /* null-terminate the stored string */
   } else goto cleanup;
@@ -86,7 +87,7 @@ int FORTRAN(write_dods)(char*filename, int* slen, int *clobber, int *swap,
   }
 
 cleanup:
-  if (fileptr) PyMem_Free(fileptr);
+  if (fileptr) FerMem_Free(fileptr, __FILE__, __LINE__);
   result = errno;
   if (f) {
     if (errno) {             /* preserve original error even if close fails */
@@ -100,8 +101,7 @@ cleanup:
 }
 
 
-int FORTRAN(write_dods_double)(char*filename, int* slen, int *clobber, int *swap, 
-                               int *length, double *data) 
+int FORTRAN(write_dods_double)(char*filename, int* slen, int *clobber, int *swap, int *length, double *data) 
 {
   FILE *f;
   int i, length_n, result = 0;
@@ -118,7 +118,8 @@ int FORTRAN(write_dods_double)(char*filename, int* slen, int *clobber, int *swap
 
   /* allocate memory and save the filename to null-terminated string */
 
-  if ( fileptr = (char *) PyMem_Malloc(sizeof(char) * (*slen + 1) ) ) {
+  fileptr = (char *) FerMem_Malloc(sizeof(char) * (*slen + 1), __FILE__, __LINE__);
+  if ( fileptr != NULL ) {
     strncpy (fileptr, filename, *slen);
     fileptr[*slen] = 0;    /* null-terminate the stored string */
   } else goto cleanup;
@@ -151,7 +152,7 @@ int FORTRAN(write_dods_double)(char*filename, int* slen, int *clobber, int *swap
   }
 
 cleanup:
-  if (fileptr) PyMem_Free(fileptr);
+  if (fileptr) FerMem_Free(fileptr, __FILE__, __LINE__);
   result = errno;
   if (f) {
     if (errno) {             /* preserve original error even if close fails */
