@@ -45,15 +45,12 @@
 
 #include <Python.h> /* make sure Python.h is first */
 #include <stdio.h>
+#include <stdlib.h>
+#include "fmtprotos.h"
 #include "string_array.h"
 
-void string_array_find_quoted_(  double *string_array_header,
-			         char *test_string,
-                                 int *test_len,
-                                 int *result_array,
-                                 int *result_array_size,
-                                 int *num_indices
-                           )
+void FORTRAN(string_array_find_quoted)(void **string_array_header, char *test_string, int *test_len, 
+                                       int *result_array, int *result_array_size, int *num_indices)
 {
    int i,j=0;
    int true_test_len, true_model_len, array_size, 
@@ -64,14 +61,12 @@ void string_array_find_quoted_(  double *string_array_header,
    int match=0, quote_offset=0;
    const char *_SQ_ = "_SQ_";
 
-FILE *fp;
-   
-   if(*(SA_Head**)string_array_header){
-      head = *((SA_Head**)string_array_header);
+   head = *string_array_header;
+   if( head != NULL ) {
       array_size = head->array_size;
       string_size = head->string_size;
  
-      tm_get_strlen_(&true_test_len, test_len, test_string);
+      FORTRAN(tm_get_strlen)(&true_test_len, test_len, test_string);
  
 /* "'" encloses the string? */
       if(test_string[0]=='\''
@@ -113,7 +108,7 @@ FILE *fp;
 
           match = 0;
 	  model_string=&(head->string_array[(p->index-1)*string_size]);
-          string_array_get_strlen_(string_array_header, &(p->index), &true_model_len);
+          FORTRAN(string_array_get_strlen)(string_array_header, &(p->index), &true_model_len);
           if(quote_offset >= 1) {
 	      if(true_model_len == true_test_len){
 		  match = 1;
@@ -150,7 +145,7 @@ FILE *fp;
 
    }
    else{
-       printf("\nString array not initialized yet!");
+       printf("\nString array not initialized yet (string_array_find_quoted)!\n");
    }
   
    *num_indices = j;
