@@ -20,26 +20,28 @@ import os
 import time
 import signal
 
+# First try to import PySide2, then try PyQt5 if that fails, and finally try PyQt4 if that fails
 try:
-    import sip
+    import PySide2
+    PYTHONQT_VERSION = 'PySide2'
 except ImportError:
-    import PyQt4.sip as sip
-try:
-    sip.setapi('QVariant', 2)
-except Exception:
-    pass
+    try:
+        import PyQt5
+        PYTHONQT_VERSION = 'PyQt5'
+    except ImportError:
+        import PyQt4
+        PYTHONQT_VERSION = 'PyQt4'
 
-# First try to import PyQt5, then try PyQt4 if that fails
-try:
-    import PyQt5
-    QT_VERSION = 5
-except ImportError:
-    import PyQt4
-    QT_VERSION = 4
-
-# Now that the PyQt version is determined, import the parts
+# Now that the Python Qt version is determined, import the parts
 # allowing any import errors to propagate out
-if QT_VERSION == 5:
+if PYTHONQT_VERSION == 'PySide2':
+    from PySide2.QtCore    import Qt, QPointF, QRectF, QSize, QTimer
+    from PySide2.QtGui     import QBrush, QColor, QImage, QPainter, \
+                                  QPalette, QPen, QPixmap, QPolygonF
+    from PySide2.QtWidgets import QAction, QApplication, QDialog, \
+                                  QFileDialog, QLabel, QMainWindow, \
+                                  QMessageBox, QPushButton, QScrollArea
+elif PYTHONQT_VERSION == 'PyQt5':
     from PyQt5.QtCore    import Qt, QPointF, QRectF, QSize, QTimer
     from PyQt5.QtGui     import QBrush, QColor, QImage, QPainter, \
                                 QPalette, QPen, QPixmap, QPolygonF
@@ -186,7 +188,7 @@ class PipedImagerPQ(QMainWindow):
 
     def closeEvent(self, event):
         '''
-        Clean up and send the WINDOW_CLOSED_MESSAGE on the response pipe 
+        Clean up and send the WINDOW_CLOSED_MESSAGE on the response pipe
         before closing the window.
         '''
         self.__timer.stop()
@@ -257,13 +259,13 @@ class PipedImagerPQ(QMainWindow):
         self.__label.resize(labelwidth, labelheight)
         # update the label from the new pixmap
         self.__label.update()
-       
+
     def clearScene(self, bkgcolor=None):
         '''
         Deletes the scene image and fills the label with bkgcolor.
-        If bkgcolor is None or an invalid color, the color used is 
-        the one used from the last clearScene or redrawScene call 
-        with a valid color (or opaque white if a color has never 
+        If bkgcolor is None or an invalid color, the color used is
+        the one used from the last clearScene or redrawScene call
+        with a valid color (or opaque white if a color has never
         been specified).
         '''
         # get the color to use for clearing (the background color)
@@ -313,7 +315,7 @@ class PipedImagerPQ(QMainWindow):
             if self.__autoscale:
                 self.__scalefactor = 1.0
                 barheights = self.menuBar().height() + self.statusBar().height()
-                self.resize(newwidth + self.__framedelta, 
+                self.resize(newwidth + self.__framedelta,
                             newheight + self.__framedelta + barheights)
             # clear the scene with the last clearing color
             self.clearScene(None)
@@ -324,7 +326,7 @@ class PipedImagerPQ(QMainWindow):
         and subsequent dictionaries imageinfo.  The image is created
         from multiple calls to this function since there is a limit
         on the size of a single object passed through a pipe.
-        
+
         The first imageinfo dictionary given when creating an image
         must define the following key and value pairs:
             "width": width of the image in pixels
@@ -344,7 +346,7 @@ class PipedImagerPQ(QMainWindow):
             "blockdata": this block of data as a bytearray
 
         On receipt of the last block of data (blocknum == numblocks)
-        the scene image will be created and the scene will be updated. 
+        the scene image will be created and the scene will be updated.
 
         Raises:
             KeyError - if one of the above keys is not given
@@ -435,7 +437,7 @@ class PipedImagerPQ(QMainWindow):
 
     def autoScaleScene(self):
         '''
-        Selects a scaling factor that maximizes the scene within the window 
+        Selects a scaling factor that maximizes the scene within the window
         frame without requiring scroll bars.  Intended to be called when
         the window size is changed by the user and auto-scaling is turn on.
 
@@ -460,7 +462,7 @@ class PipedImagerPQ(QMainWindow):
         newcwheight = int(factor * self.__sceneheight + 0.5)
         newcwwidth = int(factor * self.__scenewidth + 0.5)
 
-        # if the window does not have the correct aspect ratio, resize it so 
+        # if the window does not have the correct aspect ratio, resize it so
         # it will; this will generate another call to this method.  Otherwise,
         # scale the scene and be done.
         if self.isMaximized() or \
@@ -469,7 +471,7 @@ class PipedImagerPQ(QMainWindow):
             self.scaleScene(factor, False)
             return True
         else:
-            self.resize(newcwwidth + self.__framedelta, 
+            self.resize(newcwwidth + self.__framedelta,
                         newcwheight + self.__framedelta + barheights)
             return False
 
@@ -478,7 +480,7 @@ class PipedImagerPQ(QMainWindow):
         Scales both the horizontal and vertical directions by factor.
         Scaling factors are not accumulative.  So if the scene was
         already scaled, that scaling is "removed" before this scaling
-        factor is applied.  If resizewin is True, the main window is 
+        factor is applied.  If resizewin is True, the main window is
         resized to accommodate this new scaled scene size.
 
         If factor is zero, just switch to auto-scaling at the current
@@ -521,7 +523,7 @@ class PipedImagerPQ(QMainWindow):
                 mwheight = newlabheight + barheights + self.__framedelta
                 mwwidth = newlabwidth + self.__framedelta
                 # Do not exceed the available real estate on the screen.
-                # If autoscaling is in effect, the resize will trigger 
+                # If autoscaling is in effect, the resize will trigger
                 # any required adjustments.
                 scrnrect = QApplication.desktop().availableGeometry()
                 if mwwidth > 0.95 * scrnrect.width():
@@ -554,14 +556,14 @@ class PipedImagerPQ(QMainWindow):
                         ( "xbm",
                           "XBM - X11 Bitmap (*.xbm)" ), ]
         filters = ";;".join( [ t[1] for t in formattypes ] )
-        if QT_VERSION == 5:
-            # getSaveFileName; tr returns Python unicode strings in PyQt5/Python3
-            (fileName, fileFilter) = QFileDialog.getSaveFileName(self,
-                self.tr("Save the current image as "), self.tr(self.__lastfilename), self.tr(filters))
-        else:
-            # getSaveFileNameAndFilter; tr returns QStrings in PyQt4
+        if PYTHONQT_VERSION == 'PyQt4':
+            # getSaveFileNameAndFilter; tr returns QStrings in PyQt4 (Python2)
             (fileName, fileFilter) = QFileDialog.getSaveFileNameAndFilter(self,
                  self.tr("Save the current image as "), self.tr(self.__lastfilename), self.tr(filters))
+        else:
+            # getSaveFileName; tr returns Python unicode strings in PySide2 and PyQt5 (Python3)
+            (fileName, fileFilter) = QFileDialog.getSaveFileName(self,
+                self.tr("Save the current image as "), self.tr(self.__lastfilename), self.tr(filters))
         if fileName:
             for (fmt, fmtQName) in formattypes:
                 if self.tr(fmtQName) == fileFilter:
@@ -576,7 +578,7 @@ class PipedImagerPQ(QMainWindow):
     def saveSceneToFile(self, filename, imageformat, transparent, rastsize):
         '''
         Save the current scene to the named file.
-        
+
         If imageformat is empty or None, the format is guessed from
         the filename extension.
 
@@ -585,7 +587,7 @@ class PipedImagerPQ(QMainWindow):
 
         If given, rastsize is the pixels size of the saved image.
         If rastsize is not given, the saved image will be saved
-        at the current scaled image size.  
+        at the current scaled image size.
         '''
         # This could be called when there is no image present.
         # If this is the case, ignore the call.
@@ -650,7 +652,10 @@ class PipedImagerPQ(QMainWindow):
         milliseconds have passed.
         '''
         try:
-            starttime = time.clock()
+            if (sys.version_info[0] >= 3) and (sys.version_info[1] >= 3):
+                starttime = time.process_time()
+            else:
+                starttime = time.clock()
             # Wait up to 2 milliseconds waiting for a command.
             # This prevents unchecked spinning when there is
             # nothing to do (Qt immediately calling this method
@@ -662,7 +667,11 @@ class PipedImagerPQ(QMainWindow):
                 # more than 50 milliseconds have passed.
                 # This reduces Qt overhead when there are lots
                 # of commands waiting in the queue.
-                if (time.clock() - starttime) > 0.050:
+                if (sys.version_info[0] >= 3) and (sys.version_info[1] >= 3):
+                    elapsed = time.process_time() - starttime
+                else:
+                    elapsed = time.clock() - starttime
+                if elapsed > 0.050:
                     break
         except EOFError:
             # Assume PyFerret has shut down
@@ -909,4 +918,3 @@ def _test_pipedimagerpq():
 
 if __name__ == "__main__":
     _test_pipedimagerpq()
-
