@@ -86,6 +86,13 @@ from pyferret.fermethods import *
 
 # bindings for the PyQt-based graphics engines
 import pipedviewer.pyferretbindings
+try:
+    # the one-time setting of multiprocessing start method, 
+    # if supported, set to spawn to avoid Qt issues
+    import multiprocessing
+    multiprocessing.set_start_method('spawn')
+except:
+    pass
 
 from pyferret import graphbind
 from pyferret import regrid
@@ -269,7 +276,7 @@ pyferret_help_message = \
                       [-quiet]  [-linebuffer]  [-script <scriptname> [ <scriptarg> ... ]]
 
        -memsize:     maximum amount of memory that can be allocated for Ferret data 
-                     in mega (10^6) floats (where 1 float = 8 bytes); default is 25
+                     in mega (10^6) floats (where 1 float = 8 bytes); default is 125 == 1Gb
 
        -nodisplay    do not display to the console; a drawing can be saved using the 
                      FRAME command in any of the supported file formats.  The /QUALITY 
@@ -356,7 +363,7 @@ def init(arglist=None, enterferret=True):
     my_transparent = False
     my_unmapped = False
     my_pngonly = False
-    my_memsize = 25
+    my_memsize = 125
     my_journal = True
     my_verify = True
     my_restrict = False
@@ -486,12 +493,13 @@ def init(arglist=None, enterferret=True):
     return result
 
 
-def start(memsize=25, journal=True, verify=False, restrict=False,
+def start(memsize=125, journal=True, verify=False, restrict=False,
           server=False, unmapped=False, pngonly=False, quiet=False, 
           linebuffer=False, metaname=None, transparent=False):
     """
-    Initializes Ferret from the arguments given.  
-    Executes any Ferret commands given in $HOME/.ferret
+    Initializes Ferret from the arguments given.  If not restricted,
+    executes any Ferret commands given in ./.ferret if it exists,
+    or $HOME/.ferret if it exists and ./.ferret does not exist.
 
     Arguments:
         memsize: (number)     the maximum amount on memory, in mega (10^6) floats 
@@ -790,19 +798,29 @@ def start(memsize=25, journal=True, verify=False, restrict=False,
     for fname in std_pyefs:
         result = run("define pyfunc pyferret.%s" % fname)
 
-    # run the ${HOME}/.ferret script if it exists and not in a restricted environment
+    # if not in a restricted environment, run the ./.ferret if it exists, 
+    # or ${HOME}/.ferret script if exists and ./ferret does not
     if not restrict:
-        home_val = os.getenv('HOME')
-        if home_val:
-            init_script = os.path.join(home_val, '.ferret')
-            if os.path.exists(init_script):
-                try:
-                    result = run('go "%s"; exit /topy' % init_script)
-                except:
-                    print(" **Error: exception raised in runnning script %s" % init_script, file=sys.stderr)
-                    result = run('exit /program')
-                    # should not get here
-                    raise SystemExit
+        if os.path.exists('./.ferret'):
+            try:
+                result = run('go "./.ferret"; exit /topy')
+            except:
+                print(" **Error: exception raised in runnning script ./.ferret", file=sys.stderr)
+                result = run('exit /program')
+                # should not get here
+                raise SystemExit
+        else:
+            home_val = os.getenv('HOME')
+            if home_val:
+                init_script = os.path.join(home_val, '.ferret')
+                if os.path.exists(init_script):
+                    try:
+                        result = run('go "%s"; exit /topy' % init_script)
+                    except:
+                        print(" **Error: exception raised in runnning script %s" % init_script, file=sys.stderr)
+                        result = run('exit /program')
+                        # should not get here
+                        raise SystemExit
 
     # if journaling desired, turn it on now
     if journal:
