@@ -266,7 +266,7 @@ static char pyferretStartDocstring[] =
     "\n"
     "Optional arguments: \n"
     "    memsize = <float>: the size, in megadoubles (where a double is 8 bytes), \n"
-    "                       to allocate for Ferret's memory cache (default 25.6) \n"
+    "                       to allocate for Ferret's memory cache (default 125 == 1Gb) \n"
     "    journal = <bool>: journal Ferret commands? (default True) \n"
     "    verify = <bool>: echo Ferret commands? (default True) \n"
     "    restrict = <bool>: restrict Ferret's capabilities? (default False) \n"
@@ -294,7 +294,7 @@ static PyObject *pyferretStart(PyObject *self, PyObject *args, PyObject *kwds)
     static char *argNames[] = {"memsize", "journal", "verify", "restrict", "server",
                                "metaname", "transparent", "unmapped", "pngonly", 
                                "quiet", "linebuffer", NULL};
-    double mwMemSize = 25.6;
+    double mwMemSize = 125.0;
     PyObject *pyoJournal = NULL;
     PyObject *pyoVerify = NULL;
     PyObject *pyoRestrict = NULL;
@@ -472,6 +472,7 @@ static PyObject *pyferretStart(PyObject *self, PyObject *args, PyObject *kwds)
 
 /*
  * Called by the Ferret core to reallocate for more PPL memory
+ * Preface the message with **ERROR so it gets shown as an error within PyFerret by LAS
  */
 void reallo_ppl_memory(int new_size)
 {
@@ -479,7 +480,7 @@ void reallo_ppl_memory(int new_size)
         FerMem_Free(pplMemory, __FILE__, __LINE__);
     pplMemory = (float *) FerMem_Malloc((size_t)new_size * sizeof(float), __FILE__, __LINE__);
     if ( pplMemory == NULL ) {
-        printf("Unable to allocate the requested %d words of PLOT memory.\n", new_size);
+        printf("**ERROR: PyFerret. Unable to allocate the requested %d words of PLOT memory.\n", new_size);
         exit(1);
     }
     set_ppl_memory(pplMemory, new_size);
@@ -1347,7 +1348,7 @@ static PyObject *pyferretGetStrData(PyObject *self, PyObject *args, PyObject *kw
      */
     FORTRAN(get_str_data_array_params)(dataname, &lendataname, &arraystart, 
                                memlo, memhi, steplo, stephi, incr, axis_types,
-                               errmsg, &lenerrmsg, 1024, 64, 2112);
+                               errmsg, &lenerrmsg, 1024, 2112);
     if ( lenerrmsg > 0 ) {
         errmsg[lenerrmsg] = '\0';
         PyErr_SetString(PyExc_ValueError, errmsg);
